@@ -11,12 +11,11 @@
 #include "utils/customemoji.h"
 
 #include <QJsonObject>
+#include <QtQml/qqmlregistration.h>
 
-class Attachment;
 class Notification;
 class QNetworkReply;
 class QHttpMultiPart;
-class QFile;
 class Preferences;
 
 /**
@@ -27,6 +26,8 @@ class Preferences;
 class AbstractAccount : public QObject
 {
     Q_OBJECT
+    QML_ELEMENT
+    QML_UNCREATABLE("Abstract class")
 
     Q_PROPERTY(QString username READ username WRITE setUsername NOTIFY usernameChanged)
 
@@ -42,6 +43,7 @@ class AbstractAccount : public QObject
     Q_PROPERTY(AccountConfig *config READ config NOTIFY fetchedInstanceMetadata)
     Q_PROPERTY(bool registrationsOpen READ registrationsOpen NOTIFY fetchedInstanceMetadata)
     Q_PROPERTY(QString registrationMessage READ registrationMessage NOTIFY fetchedInstanceMetadata)
+    Q_PROPERTY(int unreadNotificationsCount READ unreadNotificationsCount NOTIFY unreadNotificationsCountChanged)
 
 public:
     /**
@@ -69,22 +71,22 @@ public:
      * @return If the application is registered
      * @sa registerApplication
      */
-    bool isRegistered() const;
+    [[nodiscard]] bool isRegistered() const;
 
     /**
      * @return If this account's instance has registrations open.
      */
-    bool registrationsOpen() const;
+    [[nodiscard]] bool registrationsOpen() const;
 
     /**
      * @return The reason why registrations are disabled.
      */
-    QString registrationMessage() const;
+    [[nodiscard]] QString registrationMessage() const;
 
     /**
      * @return The oauth2 authorization url.
      */
-    Q_INVOKABLE QUrl getAuthorizeUrl() const;
+    Q_INVOKABLE [[nodiscard]] QUrl getAuthorizeUrl() const;
 
     /**
      * @brief Sets the access token.
@@ -95,7 +97,7 @@ public:
     /**
      * @return The oauth2 token url.
      */
-    QUrl getTokenUrl() const;
+    [[nodiscard]] QUrl getTokenUrl() const;
 
     /**
      * @brief Set the oauth2 token.
@@ -107,17 +109,17 @@ public:
      * @return If the account has a token set.
      * @see setToken()
      */
-    bool haveToken() const;
+    [[nodiscard]] bool haveToken() const;
 
     /**
      * @return If the account has a username yet.
      */
-    bool hasName() const;
+    [[nodiscard]] bool hasName() const;
 
     /**
      * @return If the account has an instance uri set.
      */
-    bool hasInstanceUrl() const;
+    [[nodiscard]] bool hasInstanceUrl() const;
 
     /**
      * @brief Verifies the token with the instance and if successful, loads identity information for the account.
@@ -132,13 +134,13 @@ public:
     /**
      * @return The server-side preferences.
      */
-    Preferences *preferences() const;
+    [[nodiscard]] Preferences *preferences() const;
 
     /**
      * @return The username of the account.
      * @see setUsername()
      */
-    QString username() const;
+    [[nodiscard]] QString username() const;
 
     /**
      * @brief Sets the username for the account.
@@ -159,13 +161,13 @@ public:
     /**
      * @return The custom emojis that's accessible for this account.
      */
-    QList<CustomEmoji> customEmojis() const;
+    [[nodiscard]] QList<CustomEmoji> customEmojis() const;
 
     /**
      * @return The instance URI.
      * @see setInstanceUri()
      */
-    QString instanceUri() const;
+    [[nodiscard]] QString instanceUri() const;
 
     /**
      * @brief Sets the instance URI for the account.
@@ -176,28 +178,28 @@ public:
     /**
      * @return The max allowable length of posts in characters.
      */
-    size_t maxPostLength() const;
+    [[nodiscard]] size_t maxPostLength() const;
 
     /**
      * @return The maximum number of poll options.
      */
-    size_t maxPollOptions() const;
+    [[nodiscard]] size_t maxPollOptions() const;
 
     /**
      * @return Certain servers (like Pleroma/Akkoma) support an additional visibility type, called Local.
      * @sa Post::Visibility
      */
-    bool supportsLocalVisibility() const;
+    [[nodiscard]] bool supportsLocalVisibility() const;
 
     /**
      * @return Returns the amount of characters that URLs take. Any URL that appears in a post will only be counted by this limit.
      */
-    size_t charactersReservedPerUrl() const;
+    [[nodiscard]] size_t charactersReservedPerUrl() const;
 
     /**
      * @return The title set by the instance.
      */
-    QString instanceName() const;
+    [[nodiscard]] QString instanceName() const;
 
     /**
      * @return The identity of the account.
@@ -218,7 +220,7 @@ public:
      * @param accountId The account ID to look up.
      * @return If the identity was cached.
      */
-    bool identityCached(const QString &accountId) const;
+    [[nodiscard]] bool identityCached(const QString &accountId) const;
 
     /**
      * Get identity of the admin::account.
@@ -243,6 +245,13 @@ public:
      */
     void invalidate();
 
+    /**
+     * @brief Saves the timeline position.
+     * @param timeline Which timeline to save, right now can only be "home" or "notifications"
+     * @param lastReadId The last read post id.
+     */
+    Q_INVOKABLE void saveTimelinePosition(const QString &timeline, const QString &lastReadId);
+
     /**
      * @brief Favorite a post.
      * @param p The post object to mutate.
@@ -320,7 +329,7 @@ public:
     /**
      * @return The allowed content types of the account's instance.
      */
-    AllowedContentType allowedContentTypes() const
+    [[nodiscard]] AllowedContentType allowedContentTypes() const
     {
         return m_allowedContentTypes;
     }
@@ -329,7 +338,7 @@ public:
      * @param path The base API path.
      * @return A well-formed URL of an API path.
      */
-    QUrl apiUrl(const QString &path) const;
+    [[nodiscard]] QUrl apiUrl(const QString &path) const;
 
     /**
      * @brief Make an HTTP GET request to the server.
@@ -458,13 +467,27 @@ public:
     /**
      * @return If the account has any follow requests.
      */
-    int followRequestCount() const;
+    [[nodiscard]] int followRequestCount() const;
 
     /**
      * @brief Check against the server for any new follow requests.
      */
     virtual void checkForFollowRequests() = 0;
 
+    /**
+     * @brief Update the number of unread notifications from the server.
+     */
+    virtual void checkForUnreadNotifications() = 0;
+
+    /**
+     * @brief Resets the unread notifications count *only* on the client-side.
+     *
+     * Use checkForUnreadNotifications() if you want to check if it's reset on the server.
+     */
+    void resetUnreadNotificationsCount();
+
+    [[nodiscard]] int unreadNotificationsCount() const;
+
     /**
      * @brief Update the push notification rules.
      */
@@ -484,6 +507,12 @@ public:
      */
     Q_INVOKABLE void unfollowAccount(Identity *identity);
 
+    /**
+     * @brief Remove the given account as your follower.
+     * @param identity The account to remove as follower.
+     */
+    Q_INVOKABLE void removeFollower(Identity *identity);
+
     /**
      * @brief Block the given account.
      * @param identity The account to block.
@@ -539,17 +568,17 @@ public:
     /**
      * @return The preferred settings group name for this Account which includes the username and the instance uri.
      */
-    QString settingsGroupName() const;
+    [[nodiscard]] QString settingsGroupName() const;
 
     /**
      * @return The preferred key name for the client secret.
      */
-    QString clientSecretKey() const;
+    [[nodiscard]] QString clientSecretKey() const;
 
     /**
      * @return The preferred key name for the access token.
      */
-    QString accessTokenKey() const;
+    [[nodiscard]] QString accessTokenKey() const;
 
     /**
      * @brief Type of account action.
@@ -557,6 +586,7 @@ public:
     enum AccountAction {
         Follow, /**< Follow the account. */
         Unfollow, /**< Unfollow the account. */
+        RemoveFollower, /**< Remove the account as your follower. */
         Block, /**< Block the account. */
         Unblock, /**< Unlock the account. */
         Mute, /**< Mute the account. */
@@ -664,6 +694,11 @@ Q_SIGNALS:
      */
     void followRequestCountChanged();
 
+    /**
+     * @brief Emitted when the number of unread notifications was changed.
+     */
+    void unreadNotificationsCountChanged();
+
     /**
      * @brief Emitted when a registration error has occurred.
      * @param json The JSON body for further processing.
@@ -704,10 +739,11 @@ protected:
     bool m_registrationsOpen = false;
     QString m_registrationMessage;
     int m_followRequestCount = 0;
+    int m_unreadNotificationsCount = 0;
     QString m_redirectUri;
 
     // OAuth authorization
-    QUrlQuery buildOAuthQuery() const;
+    [[nodiscard]] QUrlQuery buildOAuthQuery() const;
 
     // updates and notifications
     void handleNotification(const QJsonDocument &doc);
