@@ -13,6 +13,7 @@
 #include "tokodon_debug.h"
 #endif
 
+#include <config.h>
 #include <qt6keychain/keychain.h>
 
 using namespace Qt::Literals::StringLiterals;
@@ -34,6 +35,7 @@ Account::Account(AccountConfig *settings, QNetworkAccessManager *nam, QObject *p
     m_preferences = new Preferences(this);
     m_config = settings;
     connect(this, &Account::authenticated, this, &Account::checkForFollowRequests);
+    connect(this, &Account::authenticated, this, &Account::checkForUnreadNotifications);
     buildFromSettings();
 }
 
@@ -257,7 +259,9 @@ QWebSocket *Account::streamingSocket(const QString &stream)
         const auto env = QJsonDocument::fromJson(message.toLocal8Bit());
         if (env.isObject() && env.object().contains("event"_L1)) {
             const auto event = stringToStreamingEventType[env.object()["event"_L1].toString()];
-            Q_EMIT streamingEvent(event, env.object()["payload"_L1].toString().toLocal8Bit());
+            if (Config::autoUpdate()) {
+                Q_EMIT streamingEvent(event, env.object()["payload"_L1].toString().toLocal8Bit());
+            }
 
             if (event == NotificationEvent) {
                 const auto doc = QJsonDocument::fromJson(env.object()["payload"_L1].toString().toLocal8Bit());
@@ -431,6 +435,18 @@ void Account::checkForFollowRequests()
     });
 }
 
+void Account::checkForUnreadNotifications()
+{
+    get(apiUrl(QStringLiteral("/api/v1/notifications/unread_count")), true, this, [this](QNetworkReply *reply) {
+        const auto unreadNotificationsObject = QJsonDocument::fromJson(reply->readAll());
+        const auto count = unreadNotificationsObject["count"_L1].toInt();
+        if (m_unreadNotificationsCount != count) {
+            m_unreadNotificationsCount = count;
+            Q_EMIT unreadNotificationsCountChanged();
+        }
+    });
+}
+
 void Account::updatePushNotifications()
 {
 #ifdef HAVE_KUNIFIEDPUSH
