@@ -37,7 +37,6 @@
 #include "tokodon_debug.h"
 #include "utils/blurhashimageprovider.h"
 #include "utils/colorschemer.h"
-#include "utils/windowcontroller.h"
 
 #ifdef Q_OS_WINDOWS
 #include <Windows.h>
@@ -113,7 +112,7 @@ int main(int argc, char *argv[])
     KAboutData about(QStringLiteral("tokodon"),
                      i18n("Tokodon"),
                      QStringLiteral(TOKODON_VERSION_STRING),
-                     i18n("Mastodon client"),
+                     i18n("Browse the Fediverse"),
                      KAboutLicense::GPL_V3,
                      i18n("© 2021-2024 Carl Schwan, 2021-2024 KDE Community"));
     about.addAuthor(i18n("Carl Schwan"),
@@ -138,7 +137,7 @@ int main(int argc, char *argv[])
 #endif
 
     QCommandLineParser parser;
-    parser.setApplicationDescription(i18n("Client for decentralized social networks like Mastodon"));
+    parser.setApplicationDescription(i18n("Browse the Fediverse"));
     parser.addPositionalArgument(QStringLiteral("urls"), i18n("Supports https and web+ap url scheme"));
 
     QCommandLineOption shareOption(QStringLiteral("share"), i18n("Share a line of text in the standalone composer."), i18n("The text to share."));
@@ -238,7 +237,7 @@ int main(int argc, char *argv[])
     NetworkAccessManagerFactory namFactory;
     engine.setNetworkAccessManagerFactory(&namFactory);
 
-    engine.addImageProvider(QLatin1String("blurhash"), new BlurhashImageProvider);
+    engine.addImageProvider(QLatin1String("blurhash"), new BlurHashImageProvider);
 
 #ifdef TEST_MODE
     AccountManager::instance().setTestMode(true);
@@ -252,6 +251,7 @@ int main(int argc, char *argv[])
     account->registerGet(url, new TestReply(QStringLiteral("search-result.json"), account));
 
     account->registerGet(account->apiUrl(QStringLiteral("/api/v1/timelines/home")), new TestReply(QStringLiteral("statuses.json"), account));
+    account->registerGet(account->apiUrl(QStringLiteral("/api/v1/notifications")), new TestReply(QStringLiteral("notifications.json"), account));
 #else
     AccountManager::instance().migrateSettings();
     AccountManager::instance().loadFromSettings();
@@ -278,23 +278,6 @@ int main(int argc, char *argv[])
     if (engine.rootObjects().isEmpty()) {
         return -1;
     }
-#ifdef HAVE_KDBUSADDONS
-    QQuickWindow *window = nullptr;
 
-    const auto rootObjects = engine.rootObjects();
-    for (auto obj : rootObjects) {
-        auto view = qobject_cast<QQuickWindow *>(obj);
-        if (view) {
-            window = view;
-            break;
-        }
-    }
-
-    if (window != nullptr) {
-        auto controller = engine.singletonInstance<WindowController *>(QStringLiteral("org.kde.tokodon"), QStringLiteral("WindowController"));
-        controller->setWindow(window);
-        controller->restoreGeometry();
-    }
-#endif
     return QCoreApplication::exec();
 }
