@@ -4,6 +4,7 @@
 #include "notification/notificationmodel.h"
 
 #include "account/abstractaccount.h"
+#include "texthandler.h"
 
 #include <KLocalizedString>
 
@@ -20,7 +21,7 @@ NotificationModel::NotificationModel(QObject *parent)
             beginResetModel();
             m_notifications.clear();
             endResetModel();
-            m_next = QUrl();
+            m_next = {};
             setLoading(false);
         }
     });
@@ -41,7 +42,7 @@ NotificationModel::NotificationModel(QObject *parent)
         beginResetModel();
         m_notifications.clear();
         endResetModel();
-        m_next = QUrl();
+        m_next = {};
         setLoading(false);
         fillTimeline();
     });
@@ -65,6 +66,12 @@ void NotificationModel::setExcludesTypes(const QStringList &excludeTypes)
     Q_EMIT excludeTypesChanged();
 }
 
+void NotificationModel::markAllNotificationsAsRead()
+{
+    m_account->saveTimelinePosition(QStringLiteral("notifications"), QString::number(m_notifications.first()->id()));
+    m_account->resetUnreadNotificationsCount();
+}
+
 void NotificationModel::fillTimeline(const QUrl &next)
 {
     if (!m_account) {
@@ -77,8 +84,7 @@ void NotificationModel::fillTimeline(const QUrl &next)
     setLoading(true);
     QUrl uri;
     if (next.isEmpty()) {
-        uri = QUrl::fromUserInput(m_account->instanceUri());
-        uri.setPath(QStringLiteral("/api/v1/notifications"));
+        uri = m_account->apiUrl(QStringLiteral("/api/v1/notifications"));
     } else {
         uri = next;
     }
@@ -96,10 +102,9 @@ void NotificationModel::fillTimeline(const QUrl &next)
             m_account->errorOccured(i18n("Error occurred when fetching the latest notification."));
             return;
         }
-        static QRegularExpression re(QStringLiteral("<(.*)>; rel=\"next\""));
-        const auto next = reply->rawHeader(QByteArrayLiteral("Link"));
-        const auto match = re.match(QString::fromUtf8(next));
-        m_next = QUrl::fromUserInput(match.captured(1));
+
+        const auto linkHeader = QString::fromUtf8(reply->rawHeader(QByteArrayLiteral("Link")));
+        m_next = TextHandler::getNextLink(linkHeader);
 
         QList<std::shared_ptr<Notification>> notifications;
         const auto values = doc.array();
@@ -127,11 +132,11 @@ void NotificationModel::fetchMore(const QModelIndex &parent)
 {
     Q_UNUSED(parent);
 
-    if (m_notifications.isEmpty() || !m_next.isValid() || m_loading) {
+    if (m_notifications.isEmpty() || !m_next || m_loading) {
         return;
     }
 
-    fillTimeline(m_next);
+    fillTimeline(m_next.value());
 }
 
 bool NotificationModel::canFetchMore(const QModelIndex &parent) const
@@ -184,6 +189,12 @@ QVariant NotificationModel::data(const QModelIndex &index, int role) const
             return QVariant::fromValue<Identity *>(post->authorIdentity().get());
         }
     } break;
+    case ReportRole:
+        return QVariant::fromValue<ReportInfo *>(notification->report());
+    case RelationshipSeveranceEventRole:
+        return QVariant::fromValue<RelationshipSeveranceEvent>(*notification->relationshipSeveranceEvent());
+    case ModerationWarningRole:
+        return QVariant::fromValue<AccountWarning>(*notification->accountWarning());
     default:
         if (post != nullptr) {
             return postData(post, role);
@@ -192,6 +203,14 @@ QVariant NotificationModel::data(const QModelIndex &index, int role) const
 
     return {};
 }
+QHash<int, QByteArray> NotificationModel::roleNames() const
+{
+    auto roles = AbstractTimelineModel::roleNames();
+    roles.insert(ReportRole, QByteArrayLiteral("report"));
+    roles.insert(RelationshipSeveranceEventRole, QByteArrayLiteral("relationshipSeveranceEvent"));
+    roles.insert(ModerationWarningRole, QByteArrayLiteral("moderationWarning"));
+    return roles;
+}
 
 void NotificationModel::actionReply(const QModelIndex &index)
 {
