@@ -38,9 +38,12 @@ QString AccountModel::displayName() const
     return m_identity->displayNameHtml();
 }
 
-void AccountModel::fillTimeline(const QString &fromId)
+void AccountModel::fillTimeline(const QString &fromId, bool backwards)
 {
-    if (m_accountId.isEmpty() || m_accountId.isNull() || loading()) {
+    Q_UNUSED(backwards)
+
+    // Media is now handled by AccountMediaTimelineModel
+    if (m_accountId.isEmpty() || m_accountId.isNull() || m_currentTab == Media || loading()) {
         return;
     }
     setLoading(true);
@@ -224,12 +227,6 @@ void AccountModel::updateTabFilters()
         m_excludeReplies = false;
         m_onlyMedia = false;
         break;
-    case Media:
-        m_excludeBoosts = true;
-        m_excludePinned = true;
-        m_excludeReplies = false;
-        m_onlyMedia = true;
-        break;
     default:
         break;
     }
