@@ -176,7 +176,7 @@ void Post::fromJson(QJsonObject obj)
     addAttachments(obj["media_attachments"_L1].toArray());
     const QJsonArray mentions = obj["mentions"_L1].toArray();
     if (obj.contains("card"_L1) && !obj["card"_L1].toObject().empty()) {
-        setCard(std::make_optional<Card>(obj["card"_L1].toObject()));
+        setCard(std::make_optional<Card>(m_parent, obj["card"_L1].toObject()));
     }
 
     if (obj.contains("application"_L1) && !obj["application"_L1].toObject().empty()) {
@@ -211,32 +211,7 @@ QDateTime Post::publishedAt() const
 
 QString Post::relativeTime() const
 {
-    const auto current = QDateTime::currentDateTime();
-    const auto publishingDate = publishedAt();
-    const auto secsTo = publishingDate.secsTo(current);
-    const auto daysTo = publishingDate.daysTo(current);
-    if (secsTo < 0) {
-        return i18n("in the future");
-    } else if (secsTo < 60) {
-        return i18n("%1s", qCeil(secsTo));
-    } else if (secsTo < 60 * 60) {
-        return i18n("%1m", qCeil(secsTo / 60));
-    } else if (secsTo < 60 * 60 * 24) {
-        return i18n("%1h", qCeil(secsTo / (60 * 60)));
-    } else if (daysTo < 7) {
-        return i18n("%1d", qCeil(daysTo));
-    } else if (daysTo < 365) {
-        const auto weeksTo = qCeil(daysTo / 7);
-        if (weeksTo < 5) {
-            return i18np("1 week ago", "%1 weeks ago", weeksTo);
-        } else {
-            const auto monthsTo = qCeil(daysTo / 30);
-            return i18np("1 month ago", "%1 months ago", monthsTo);
-        }
-    } else {
-        const auto yearsTo = qCeil(daysTo / 365);
-        return i18np("1 year ago", "%1 years ago", yearsTo);
-    }
+    return TextHandler::getRelativeDateTime(publishedAt());
 }
 
 QString Post::absoluteTime() const
@@ -509,9 +484,9 @@ void Post::processContent(const QJsonObject &obj)
         };
 
         for (const QString &tagFormat : tagFormats) {
-            processedHtml = processedHtml.replace(baseUrl + QStringLiteral("/%1/").arg(tagFormat) + tagObj["name"_L1].toString(),
-                                                  QStringLiteral("hashtag:/") + tagObj["name"_L1].toString(),
-                                                  Qt::CaseInsensitive);
+            const QString tagName = tagObj["name"_L1].toString();
+
+            processedHtml.replace(QStringLiteral("%1/%2/%3").arg(baseUrl, tagFormat, tagName), QStringLiteral("hashtag:/%1").arg(tagName), Qt::CaseInsensitive);
         }
     }
 
@@ -520,8 +495,7 @@ void Post::processContent(const QJsonObject &obj)
 
     for (const auto &mention : mentions) {
         const auto mentionObj = mention.toObject();
-        processedHtml =
-            processedHtml.replace(mentionObj["url"_L1].toString(), QStringLiteral("account:/") + mentionObj["id"_L1].toString(), Qt::CaseInsensitive);
+        processedHtml.replace(mentionObj["url"_L1].toString(), QStringLiteral("account:/") + mentionObj["id"_L1].toString(), Qt::CaseInsensitive);
     }
 
     // Remove the standalone tags from the main content
@@ -532,21 +506,41 @@ void Post::processContent(const QJsonObject &obj)
     m_content = standaloneContent;
 }
 
-Card::Card(QJsonObject card)
+Card::Card(AbstractAccount *account, QJsonObject card)
     : m_card(card)
+    , m_account(account)
 {
 }
 
 QString Card::authorName() const
 {
+    if (const auto author = authorObject()) {
+        return (*author)["name"_L1].toString();
+    }
     return m_card[QLatin1String("author_name")].toString();
 }
 
 QString Card::authorUrl() const
 {
+    if (const auto author = authorObject()) {
+        return (*author)["url"_L1].toString();
+    }
     return m_card[QLatin1String("author_url")].toString();
 }
 
+Identity *Card::authorIdentity() const
+{
+    if (m_account != nullptr) {
+        if (const auto author = authorObject()) {
+            const auto account = (*author)["account"_L1];
+            if (!account.isNull()) {
+                return m_account->identityLookup(account["id"_L1].toString(), account.toObject()).get();
+            }
+        }
+    }
+    return nullptr;
+}
+
 QString Card::blurhash() const
 {
     return m_card[QLatin1String("blurhash")].toString();
@@ -606,6 +600,17 @@ QUrl Card::url() const
     return QUrl::fromUserInput(m_card[QLatin1String("url")].toString());
 }
 
+std::optional<QJsonObject> Card::authorObject() const
+{
+    if (m_card.contains("authors"_L1)) {
+        const auto &authors = m_card["authors"_L1].toArray();
+        if (!authors.isEmpty()) {
+            return authors.first().toObject();
+        }
+    }
+    return std::nullopt;
+}
+
 Application::Application(QJsonObject application)
     : m_application(application)
 {
