@@ -63,20 +63,20 @@ void TimelineModel::init()
     fillTimeline();
 }
 
-void TimelineModel::fetchedTimeline(const QByteArray &data, bool alwaysAppendToEnd)
+int TimelineModel::fetchedTimeline(const QByteArray &data, bool alwaysAppendToEnd)
 {
     QList<Post *> posts;
 
     const auto doc = QJsonDocument::fromJson(data);
 
     if (!doc.isArray()) {
-        return;
+        return 0;
     }
 
     const auto array = doc.array();
 
     if (array.isEmpty()) {
-        return;
+        return 0;
     }
 
     std::transform(array.cbegin(), array.cend(), std::back_inserter(posts), [this](const QJsonValue &value) -> Post * {
@@ -101,6 +101,38 @@ void TimelineModel::fetchedTimeline(const QByteArray &data, bool alwaysAppendToE
                                }),
                 posts.end());
 
+    for (auto &post : posts) {
+        // If we are still waiting on the reply identity, make sure to update it's row
+        if (!post->inReplyTo().isEmpty() && post->replyIdentity() == nullptr) {
+            connect(
+                post,
+                &Post::replyIdentityChanged,
+                this,
+                [this, post] {
+                    const int row = m_timeline.indexOf(post);
+                    if (row != -1) {
+                        Q_EMIT dataChanged(index(row, 0), index(row, 0), {ReplyAuthorIdentityRole});
+                    }
+                },
+                Qt::SingleShotConnection);
+        }
+
+        // Ditto for boost identity
+        if (!post->boosted() && post->boostIdentity() == nullptr) {
+            connect(
+                post,
+                &Post::boostIdentity,
+                this,
+                [this, post] {
+                    const int row = m_timeline.indexOf(post);
+                    if (row != -1) {
+                        Q_EMIT dataChanged(index(row, 0), index(row, 0), {BoostAuthorIdentityRole});
+                    }
+                },
+                Qt::SingleShotConnection);
+        }
+    }
+
     if (!m_timeline.isEmpty()) {
         if (alwaysAppendToEnd) {
             beginInsertRows({}, m_timeline.size(), m_timeline.size() + posts.size() - 1);
@@ -126,6 +158,8 @@ void TimelineModel::fetchedTimeline(const QByteArray &data, bool alwaysAppendToE
         m_timeline = posts;
         endInsertRows();
     }
+
+    return posts.size();
 }
 
 void TimelineModel::fetchMore(const QModelIndex &parent)
