@@ -23,18 +23,18 @@ class TimelineModel : public AbstractTimelineModel
 public:
     explicit TimelineModel(QObject *parent = nullptr);
 
-    int rowCount(const QModelIndex &parent) const override;
-    QVariant data(const QModelIndex &index, int role) const override;
+    [[nodiscard]] int rowCount(const QModelIndex &parent) const override;
+    [[nodiscard]] QVariant data(const QModelIndex &index, int role) const override;
 
     /**
      * @brief Start filling the timeline starting at @p fromId
      */
-    virtual void fillTimeline(const QString &fromId = {}) = 0;
+    virtual void fillTimeline(const QString &fromId = {}, bool backwards = false) = 0;
 
     /**
      * @return A translated label for the timeline (e.g. "Home")
      */
-    virtual QString displayName() const = 0;
+    [[nodiscard]] virtual QString displayName() const = 0;
 
     /**
      * @brief Handle an incoming streaming event.
@@ -110,8 +110,12 @@ Q_SIGNALS:
 
 protected:
     void fetchMore(const QModelIndex &parent) override;
-    bool canFetchMore(const QModelIndex &parent) const override;
-    void fetchedTimeline(const QByteArray &array, bool alwaysAppendToEnd = false);
+    [[nodiscard]] bool canFetchMore(const QModelIndex &parent) const override;
+
+    /**
+     * @return The number of posts added to the timeline.
+     */
+    int fetchedTimeline(const QByteArray &array, bool alwaysAppendToEnd = false);
 
     AccountManager *m_manager = nullptr;
 
